Dimensionality reduction
========================

Since the size of the embeddings obtained by transformer models are typically very large, ``nlpsig`` provides an interface to a number of dimensionality reduction techniques.
The functionality for performing dimensionality reduction within the package can be done through the ``nlpsig.DimReduce`` class.
There is also functionality to visualise embeddings via the ``nlpsig.PlotEmbedding`` class.

.. automodule:: nlpsig.dimensionality_reduction
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: nlpsig.plot_embedding
   :members:
   :undoc-members:
   :show-inheritance:
